@@ -31,15 +31,14 @@
 #include <fcntl.h>
 
 #include <glib.h>
-#include <libyahoo2/yahoo2.h>
+#include <yahoo2.h>
 
-#include <config.h>
 #include "freehoo.h"
 #include "interpreter.h"
-#include "messenger.h"
 #include "fh-utils.h"
-#include "yahoo-wrapper.h"
-
+#include "yahoo-adapter.h"
+#include "yahoo-backend.h"
+#include <config.h>
 
 char *commands[] = { "?send", "?who", "?add", "?remove", "?reject", "?ignore", 
 		     "?ignorelist", "?unignore", "?help", "?status", 
@@ -49,7 +48,7 @@ char *commands[] = { "?send", "?who", "?add", "?remove", "?reject", "?ignore",
 		     "?send-file", FH_ROBOT, NULL
 };
 
-YList * conferences = NULL;
+extern YList *conferences;
 
 SCM dynamic_commands = SCM_UNSPECIFIED;
 
@@ -190,7 +189,7 @@ void *
 get_nth_buddy(int index)
 {
   int i = 0;
-  YList *buds = (get_fh_session ())->buddy_list;
+  YList *buds = get_fh_buddies ();
   for(; buds; buds = buds->next) 
     {
       if (i == index)
@@ -209,7 +208,7 @@ command_generator (const char *text, int stat)
   unsigned long dynamic_commands_count;
   char *dynamic_command;
   char *name;
-  struct yahoo_buddy *temp_buddy;
+  yahoo_account *temp_buddy;
 
   if (!stat)
     {
@@ -230,10 +229,10 @@ command_generator (const char *text, int stat)
       || (strncmp (rl_line_buffer, "?unignore ", 10) == 0))
     {
 
-      while((temp_buddy = (struct yahoo_buddy *) get_nth_buddy (i)))
+      while((temp_buddy = (yahoo_account *) get_nth_buddy (i)))
 	{
-	  i++;	  
-	  name = temp_buddy->id;
+	  i++;
+	  name = temp_buddy->yahoo_id;
 	  if (!name || (name[0] == 0))
 	    continue;
 
@@ -294,11 +293,11 @@ command_generator (const char *text, int stat)
 	return (char *) strdup (name);
     }
 
-  while((temp_buddy = (struct yahoo_buddy *) get_nth_buddy (buddy_index)))
+  while((temp_buddy = (yahoo_account *) get_nth_buddy (buddy_index)))
     {
       buddy_index++;
       
-      name = temp_buddy->id;
+      name = temp_buddy->yahoo_id;
       if (!name || (name[0] == 0))
 	continue;
 
@@ -385,13 +384,19 @@ interpreter (char *line)
   
   if (strcasecmp (command, "?refresh") == 0)
     {
-      yahoo_get_list ((get_fh_session ())->session_id); // Get buddy list and ignore list from server
-      yahoo_refresh ((get_fh_session ())->session_id); // refresh buddies status
-      (get_fh_session ())->buddy_list = (YList *)yahoo_get_buddylist ((get_fh_session ())->session_id);
-      (get_fh_session ())->ignore_list = (YList *)yahoo_get_ignorelist ((get_fh_session ())->session_id);
+      YList *buds, *igns;
+
+      yahoo_get_list (get_fh_session ()->id); // Get buddy list and ignore list from server
+      yahoo_refresh (get_fh_session ()->id); // Refresh buddies status
+
+      buds = (YList *) yahoo_get_buddylist (get_fh_session ()->id); // Get buddy list from server
+      ext_yahoo_got_buddies (get_fh_session ()->id, buds); // Update "buddies" global variable
+
+      igns = (YList *) yahoo_get_ignorelist (get_fh_session ()->id); // Get ignore list from server
+      ext_yahoo_got_ignore (get_fh_session ()->id, igns); // Update "ignore" global variable
       return;
     }
-  
+
   if (strcasecmp (command, "?add") == 0)
     {
       if (line && *line)
@@ -492,14 +497,13 @@ interpreter (char *line)
       return;
     }
 
-
   if (strcasecmp (command, "?who") == 0)
     {
       display_buddy_list ();
       return;
     }
 
-  if (strcasecmp (command, "?ignore-list") == 0)
+  if (strcasecmp (command, "?ignorelist") == 0)
     {
       display_ignore_list ();
       return;
@@ -824,7 +828,7 @@ command_status (char *line)
 		  "type \"?help ?status\" for proper syntax\n");
 	  return;
 	}
-	yahoo_set_away ((get_fh_session ())->session_id,
+	yahoo_set_away (get_fh_session ()->id,
 			current_status, 
 			current_status_msg,
 			1);
@@ -835,7 +839,7 @@ command_status (char *line)
     }
   else
     {
-      yahoo_set_away ((get_fh_session ())->session_id, 
+      yahoo_set_away (get_fh_session ()->id, 
 		      current_status,
 		      NULL,
 		      1);
@@ -860,13 +864,13 @@ command_send_message (char *line)
     }
 
   cr = find_conf_room_by_name_and_id
-    ((get_fh_session ())->session_id, user_id);
+    (get_fh_session ()->id, user_id);
 
   if (line && *line)
     {
       if (cr)
 	{
-	  yahoo_conference_message ((get_fh_session ())->session_id,
+	  yahoo_conference_message (get_fh_session ()->id,
 				    NULL, cr->members, user_id, line, 0);
 	  set_current_target_buddy (user_id);
 	}
@@ -890,8 +894,17 @@ command_buddy_add (char *line)
   
   group = get_token (&line);
   
-  yahoo_add_buddy ((get_fh_session ())->session_id, user_id, 
-		   ((group == NULL) ? FH_DEFAULT_GROUP : group));
+  /*
+    FIXME: Visu, Aug 23, 2004:
+    ==========================
+    1. The following function prototype is changed from previous
+       libyahoo2 versions.
+    2. The changes is the extra parameter (char *) at the end, For
+       now, NULL string is passed, with which its working fine. This
+       needs a revisit and approprite string to be passed if required.
+  */
+  yahoo_add_buddy (get_fh_session ()->id, user_id, 
+		   ((group == NULL) ? FH_DEFAULT_GROUP : group), "");
 }
 
 void
@@ -899,7 +912,7 @@ command_buddy_remove (char *line)
 {
   char *user_id = NULL;
   char *group = NULL;
-  fh_buddy *hoob = NULL;
+  yahoo_account *hoob = NULL;
 
   user_id = get_token (&line);
   if (user_id == (char *) NULL)
@@ -922,7 +935,7 @@ command_buddy_remove (char *line)
     }
 
   
-  yahoo_remove_buddy ((get_fh_session ())->session_id, user_id,
+  yahoo_remove_buddy (get_fh_session ()->id, user_id,
 		      group);
 }
 
@@ -942,14 +955,14 @@ command_buddy_reject (char *line)
   mesg = get_token (&line);
   if (!mesg)
     mesg = "";
-  yahoo_reject_buddy((get_fh_session ())->session_id, user_id, mesg);
+  yahoo_reject_buddy (get_fh_session ()->id, user_id, mesg);
 }
 
 void
 command_buddy_ignore (char *line)
 {
   char *user_id = NULL;
-  fh_buddy *hoob = NULL;
+  yahoo_account *hoob = NULL;
 
   user_id = get_token (&line);
   if (user_id == (char *) NULL)
@@ -961,7 +974,7 @@ command_buddy_ignore (char *line)
   hoob = g_hash_table_lookup (fh_buddy_list, user_id);
   if (!hoob)
     {
-      yahoo_ignore_buddy ((get_fh_session ())->session_id,
+      yahoo_ignore_buddy (get_fh_session ()->id,
 			  user_id, 0);
       return;
     }
@@ -984,7 +997,7 @@ command_buddy_unignore (char *line)
       return;
     }
   
-  yahoo_ignore_buddy ((get_fh_session ())->session_id,
+  yahoo_ignore_buddy (get_fh_session ()->id,
 		      user_id, 1);
 }
 
@@ -998,7 +1011,8 @@ command_eval_scheme_str (char *line)
 void
 command_load_scheme_file (char *line)
 {
-  gh_eval_file_with_standard_handler (line);
+  /* gh_eval_file_with_standard_handler (line); */
+  fh_load (line);
   scm_force_output (scm_current_output_port ());
 }
 
@@ -1138,10 +1152,10 @@ command_default_handler (char *command, char *line)
   conf_room * cr;
 
   cr = find_conf_room_by_name_and_id
-    ((get_fh_session ())->session_id, command);
+    (get_fh_session ()->id, command);
   if (cr)
     {
-      yahoo_conference_message ((get_fh_session ())->session_id,
+      yahoo_conference_message (get_fh_session ()->id,
 				NULL, cr->members, command, line, 0);
       set_current_target_buddy (command);
     }
@@ -1151,19 +1165,6 @@ command_default_handler (char *command, char *line)
     }
 }
 
-conf_room * 
-find_conf_room_by_name_and_id(int id, const char * name)
-{
-	YList * l;
-	for(l = conferences; l; l=l->next) 
-	  {
-		conf_room * cr = l->data;
-		if(cr->id == id && !strcmp(name, cr->room_name)) 
-			return cr;
-	  }
-	return NULL;
-}
-
 void
 command_conf_list (char *line)
 {
@@ -1194,8 +1195,7 @@ command_conf_add (char *line)
       return;
     }
 
-  cr = find_conf_room_by_name_and_id(get_fh_session
-				     ()->session_id, room);
+  cr = find_conf_room_by_name_and_id (get_fh_session ()->id, room);
   if (!cr)
     {
       printf ("No such room: <%s>\n", room);
@@ -1207,8 +1207,8 @@ command_conf_add (char *line)
 	return;
     }
   
-  cr->members = y_list_append(cr->members, strdup(member));
-  yahoo_conference_addinvite((get_fh_session ())->session_id,
+  cr->members = y_list_append (cr->members, strdup(member));
+  yahoo_conference_addinvite (get_fh_session ()->id,
 			     NULL, member, room, cr->members, "Join my conference");
 }
 
@@ -1225,8 +1225,7 @@ command_conf_begin (char *line)
       return;
     }
 
-  if (find_conf_room_by_name_and_id (get_fh_session
-				     ()->session_id, room))
+  if (find_conf_room_by_name_and_id (get_fh_session ()->id, room))
     return;
 
   cr = calloc (1, sizeof(conf_room));
@@ -1241,12 +1240,11 @@ command_conf_begin (char *line)
       cr->members = y_list_append(cr->members, strdup(member));
     }
   
-  cr->id = (get_fh_session ())->session_id;
+  cr->id = get_fh_session ()->id;
   cr->joined = 1;
-  conferences = y_list_append(conferences, cr);
-  cr->members = y_list_append(cr->members,strdup((get_fh_session
-						  ())->login_id));
-  yahoo_conference_invite((get_fh_session ())->session_id, NULL,
+  conferences = y_list_append (conferences, cr);
+  cr->members = y_list_append (cr->members, strdup (get_fh_session ()->yahoo_id));
+  yahoo_conference_invite (get_fh_session ()->id, NULL,
 			  cr->members, cr->room_name, "Join my conference");
   // AUTO-INSERT-MODE
   set_current_target_buddy (cr->room_name);
@@ -1256,8 +1254,7 @@ void
 command_conf_quit (char *line)
 {
   char *room = get_token (&line);
-  conf_room * cr = find_conf_room_by_name_and_id(get_fh_session
-						 ()->session_id, room);
+  conf_room * cr = find_conf_room_by_name_and_id (get_fh_session ()->id, room);
 		
   if(!cr) 
     {
@@ -1265,7 +1262,7 @@ command_conf_quit (char *line)
       return;
     }
 
-  yahoo_conference_logoff ((get_fh_session ())->session_id,
+  yahoo_conference_logoff (get_fh_session ()->id,
 			   NULL, cr->members, room);
 
   conferences = y_list_remove (conferences, cr);
@@ -1293,15 +1290,14 @@ command_conf_decline (char *line)
   if (!msg)
     msg = "Thanks, but no thanks!";
     		
-  cr = find_conf_room_by_name_and_id ((get_fh_session
-				       ())->session_id, room);
+  cr = find_conf_room_by_name_and_id (get_fh_session ()->id, room);
   if(!cr)
     {
       printf ("No such room: <%s>\n", room);
       return;
     }
 
-  yahoo_conference_decline((get_fh_session ()->session_id),
+  yahoo_conference_decline (get_fh_session ()->id,
 			   NULL, cr->members, room,msg);
 
   conferences = y_list_remove(conferences, cr);
@@ -1326,7 +1322,7 @@ command_conf_join (char *line)
   YList * l;
   char *room = get_token (&line);
   conf_room * cr = find_conf_room_by_name_and_id
-    ((get_fh_session ())->session_id, room);
+    (get_fh_session ()->id, room);
 
   if(!cr)
     {
@@ -1338,13 +1334,13 @@ command_conf_join (char *line)
   for (l = cr->members; l; l=l->next) 
     {
       char * w = l->data;
-      if(!strcmp(w, get_fh_session ()->login_id))
+      if (!strcmp (w, get_fh_session ()->yahoo_id))
 	break;
     }
   if (!l)
     cr->members = y_list_append (cr->members,
-				 strdup((get_fh_session ())->login_id));
-  yahoo_conference_logon((get_fh_session ())->session_id, NULL,
+				 strdup (get_fh_session ()->yahoo_id));
+  yahoo_conference_logon (get_fh_session ()->id, NULL,
 			 cr->members, room);
   // AUTO-INSERT-MODE
   set_current_target_buddy (room);
@@ -1357,7 +1353,7 @@ command_conf_send (char *line)
   char *msg = line;
 
   conf_room * cr = find_conf_room_by_name_and_id
-    ((get_fh_session ())->session_id, room);
+    (get_fh_session ()->id, room);
 
   if(!cr)
     {
@@ -1367,7 +1363,7 @@ command_conf_send (char *line)
 
   if (!msg)
     return;
-  yahoo_conference_message ((get_fh_session ())->session_id,
+  yahoo_conference_message (get_fh_session ()->id,
 			    NULL, cr->members, room, msg, 0);
   // AUTO-INSERT-MODE
   set_current_target_buddy (room);
